@@ -16,12 +16,14 @@
  */
 package org.apache.commons.validator.routines;
 
-import org.apache.commons.validator.routines.checkdigit.CheckDigit;
-import org.apache.commons.validator.routines.checkdigit.LuhnCheckDigit;
 import java.io.Serializable;
+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
-import java.util.ArrayList;
+
+import org.apache.commons.validator.GenericValidator;
+import org.apache.commons.validator.routines.checkdigit.CheckDigit;
+import org.apache.commons.validator.routines.checkdigit.LuhnCheckDigit;
 
 /**
  * Perform credit card validations.
@@ -73,21 +75,14 @@ import java.util.ArrayList;
  * This can be combined with a list of {@code CodeValidator}s
  * </p>
  * <p>
- * More information can be found in Michael Gilleland's essay 
+ * More information can be found in Michael Gilleland's essay
  * <a href="http://web.archive.org/web/20120614072656/http://www.merriampark.com/anatomycc.htm">Anatomy of Credit Card Numbers</a>.
  * </p>
  *
- * @version $Revision$
- * @since Validator 1.4
+ * @since 1.4
  */
 public class CreditCardValidator implements Serializable {
 
-    private static final long serialVersionUID = 5955978921148959496L;
-
-    private static final int MIN_CC_LENGTH = 12; // minimum allowed length
-
-    private static final int MAX_CC_LENGTH = 19; // maximum allowed length
-
     /**
      * Class that represents a credit card range.
      * @since 1.6
@@ -106,7 +101,8 @@ public class CreditCardValidator implements Serializable {
          * The low and high parameters may be shorter than the length
          * of an IIN (currently 6 digits) in which case subsequent digits
          * are ignored and may range from 0-9.
-         * <br>
+         * </p>
+         * <p>
          * The low and high parameters may be different lengths.
          * e.g. Discover "644" and "65".
          * </p>
@@ -115,7 +111,7 @@ public class CreditCardValidator implements Serializable {
          * @param minLen the minimum length of the entire number
          * @param maxLen the maximum length of the entire number
          */
-        public CreditCardRange(String low, String high, int minLen, int maxLen) {
+        public CreditCardRange(final String low, final String high, final int minLen, final int maxLen) {
             this.low = low;
             this.high = high;
             this.minLen = minLen;
@@ -130,15 +126,16 @@ public class CreditCardValidator implements Serializable {
          * The low and high parameters may be shorter than the length
          * of an IIN (currently 6 digits) in which case subsequent digits
          * are ignored and may range from 0-9.
-         * <br>
+         * </p>
+         * <p>
          * The low and high parameters may be different lengths.
          * e.g. Discover "644" and "65".
          * </p>
-         * @param low the low digits of the IIN range 
+         * @param low the low digits of the IIN range
          * @param high the high digits of the IIN range
          * @param lengths array of valid lengths
          */
-        public CreditCardRange(String low, String high, int [] lengths) {
+        public CreditCardRange(final String low, final String high, final int [] lengths) {
             this.low = low;
             this.high = high;
             this.minLen = -1;
@@ -147,6 +144,12 @@ public class CreditCardValidator implements Serializable {
         }
     }
 
+    private static final long serialVersionUID = 5955978921148959496L;
+
+    private static final int MIN_CC_LENGTH = 12; // minimum allowed length
+
+    private static final int MAX_CC_LENGTH = 19; // maximum allowed length
+
     /**
      * Option specifying that no cards are allowed.  This is useful if
      * you want only custom card types to validate so you turn off the
@@ -200,12 +203,6 @@ public class CreditCardValidator implements Serializable {
     @Deprecated
     public static final long MASTERCARD_PRE_OCT2016 = 1 << 6; // CHECKSTYLE IGNORE MagicNumber
 
-
-    /**
-     * The CreditCardTypes that are allowed to pass validation.
-     */
-    private final List<CodeValidator> cardTypes = new ArrayList<CodeValidator>();
-
     /**
      * Luhn checkdigit validator for the card numbers.
      */
@@ -213,56 +210,59 @@ public class CreditCardValidator implements Serializable {
 
     /**
      * American Express (Amex) Card Validator
-     * <p>
-     * 34xxxx (15) <br>
-     * 37xxxx (15) <br>
+     * <ul>
+     * <li>34xxxx (15)</li>
+     * <li>37xxxx (15)</li>
+     * </ul>
      */
     public static final CodeValidator AMEX_VALIDATOR = new CodeValidator("^(3[47]\\d{13})$", LUHN_VALIDATOR);
 
     /**
      * Diners Card Validator
-     * <p>
-     * 300xxx - 305xxx (14) <br>
-     * 3095xx (14) <br>
-     * 36xxxx (14) <br>
-     * 38xxxx (14) <br>
-     * 39xxxx (14) <br>
+     * <ul>
+     * <li>300xxx - 305xxx (14)</li>
+     * <li>3095xx (14)</li>
+     * <li>36xxxx (14)</li>
+     * <li>38xxxx (14)</li>
+     * <li>39xxxx (14)</li>
+     * </ul>
      */
     public static final CodeValidator DINERS_VALIDATOR = new CodeValidator("^(30[0-5]\\d{11}|3095\\d{10}|36\\d{12}|3[8-9]\\d{12})$", LUHN_VALIDATOR);
 
     /**
      * Discover Card regular expressions
-     * <p>
-     * 6011xx (16) <br>
-     * 644xxx - 65xxxx (16) <br>
+     * <ul>
+     * <li>6011xx (16)</li>
+     * <li>644xxx - 65xxxx (16)</li>
+     * </ul>
      */
-    private static final RegexValidator DISCOVER_REGEX = new RegexValidator(new String[] {"^(6011\\d{12,13})$", "^(64[4-9]\\d{13})$", "^(65\\d{14})$", "^(62[2-8]\\d{13})$"});
+    private static final RegexValidator DISCOVER_REGEX = new RegexValidator("^(6011\\d{12,13})$", "^(64[4-9]\\d{13})$", "^(65\\d{14})$", "^(62[2-8]\\d{13})$");
 
     /** Discover Card Validator */
     public static final CodeValidator DISCOVER_VALIDATOR = new CodeValidator(DISCOVER_REGEX, LUHN_VALIDATOR);
 
     /**
      * Mastercard regular expressions
-     * <p>
-     * 2221xx - 2720xx (16) <br>
-     * 51xxx - 55xxx (16) <br>
+     * <ul>
+     * <li>2221xx - 2720xx (16)</li>
+     * <li>51xxx - 55xxx (16)</li>
+     * </ul>
      */
     private static final RegexValidator MASTERCARD_REGEX = new RegexValidator(
-        new String[] {
-            "^(5[1-5]\\d{14})$",  // 51 - 55 (pre Oct 2016)
+            "^(5[1-5]\\d{14})$",   // 51 - 55 (pre Oct 2016)
             // valid from October 2016
-            "^(2221\\d{12})$",    // 222100 - 222199
-            "^(222[2-9]\\d{12})$",// 222200 - 222999
-            "^(22[3-9]\\d{13})$", // 223000 - 229999
-            "^(2[3-6]\\d{14})$",  // 230000 - 269999
-            "^(27[01]\\d{13})$",  // 270000 - 271999
-            "^(2720\\d{12})$",    // 272000 - 272099
-        });
+            "^(2221\\d{12})$",     // 222100 - 222199
+            "^(222[2-9]\\d{12})$", // 222200 - 222999
+            "^(22[3-9]\\d{13})$",  // 223000 - 229999
+            "^(2[3-6]\\d{14})$",   // 230000 - 269999
+            "^(27[01]\\d{13})$",   // 270000 - 271999
+            "^(2720\\d{12})$"      // 272000 - 272099
+        );
 
     /** Mastercard Card Validator */
     public static final CodeValidator MASTERCARD_VALIDATOR = new CodeValidator(MASTERCARD_REGEX, LUHN_VALIDATOR);
 
-    /** 
+    /**
      * Mastercard Card Validator (pre Oct 2016)
      * @deprecated for use until Oct 2016 only
      */
@@ -273,18 +273,118 @@ public class CreditCardValidator implements Serializable {
      * Visa Card Validator
      * <p>
      * 4xxxxx (13 or 16)
+     * </p>
      */
     public static final CodeValidator VISA_VALIDATOR = new CodeValidator("^(4)(\\d{12}|\\d{15})$", LUHN_VALIDATOR);
 
-    /** VPay (Visa) Card Validator
+    /**
+     * VPay (Visa) Card Validator
      * <p>
-     * 4xxxxx (13-19) 
+     * 4xxxxx (13-19)
+     * </p>
      * @since 1.5.0
      */
     public static final CodeValidator VPAY_VALIDATOR = new CodeValidator("^(4)(\\d{12,18})$", LUHN_VALIDATOR);
 
+    // package protected for unit test access
+    static CodeValidator createRangeValidator(final CreditCardRange[] creditCardRanges, final CheckDigit digitCheck) {
+        return new CodeValidator(
+                // must be numeric (rest of validation is done later)
+                new RegexValidator("(\\d+)") {
+                    private static final long serialVersionUID = 1L;
+                    private final transient CreditCardRange[] ccr = creditCardRanges.clone();
+
+                    @Override
+                    public boolean isValid(final String value) {
+                        return validate(value) != null;
+                    }
+
+                    @Override
+                    public String[] match(final String value) {
+                        return new String[] { validate(value) };
+                    }
+
+                    @Override
+                    // must return full string
+                    public String validate(final String value) {
+                        if (super.match(value) != null) {
+                            final int length = value.length();
+                            for (final CreditCardRange range : ccr) {
+                                if (validLength(length, range)) {
+                                    if (range.high == null) { // single prefix only
+                                        if (value.startsWith(range.low)) {
+                                            return value;
+                                        }
+                                    } else if (range.low.compareTo(value) <= 0 // no need to trim value here
+                                            &&
+                                    // here we have to ignore digits beyond the prefix
+                                            range.high.compareTo(value.substring(0, range.high.length())) >= 0) {
+                                        return value;
+                                    }
+                                }
+                            }
+                        }
+                        return null;
+                    }
+                }, digitCheck);
+    }
+
     /**
-     * Create a new CreditCardValidator with default options.
+     * Creates a new generic CreditCardValidator which validates the syntax and check digit only.
+     * Does not check the Issuer Identification Number (IIN)
+     *
+     * @return the validator
+     * @since 1.6
+     */
+    public static CreditCardValidator genericCreditCardValidator() {
+        return genericCreditCardValidator(MIN_CC_LENGTH, MAX_CC_LENGTH);
+    }
+
+    /**
+     * Creates a new generic CreditCardValidator which validates the syntax and check digit only.
+     * Does not check the Issuer Identification Number (IIN)
+     *
+     * @param length exact length
+     * @return the validator
+     * @since 1.6
+     */
+    public static CreditCardValidator genericCreditCardValidator(final int length) {
+        return genericCreditCardValidator(length, length);
+    }
+
+    /**
+     * Creates a new generic CreditCardValidator which validates the syntax and check digit only.
+     * Does not check the Issuer Identification Number (IIN)
+     *
+     * @param minLen minimum allowed length
+     * @param maxLen maximum allowed length
+     * @return the validator
+     * @since 1.6
+     */
+    public static CreditCardValidator genericCreditCardValidator(final int minLen, final int maxLen) {
+        return new CreditCardValidator(new CodeValidator[] {new CodeValidator("(\\d+)", minLen, maxLen, LUHN_VALIDATOR)});
+    }
+
+    // package protected for unit test access
+    static boolean validLength(final int valueLength, final CreditCardRange range) {
+        if (range.lengths != null) {
+            for (final int length : range.lengths) {
+                if (valueLength == length) {
+                    return true;
+                }
+            }
+            return false;
+        }
+        return valueLength >= range.minLen && valueLength <= range.maxLen;
+    }
+
+    /**
+     * The CreditCardTypes that are allowed to pass validation.
+     */
+    private final List<CodeValidator> cardTypes = new ArrayList<>();
+
+    /**
+     * Constructs a new CreditCardValidator with default options.
      * The default options are:
      * AMEX, VISA, MASTERCARD and DISCOVER
      */
@@ -293,14 +393,56 @@ public class CreditCardValidator implements Serializable {
     }
 
     /**
-     * Create a new CreditCardValidator with the specified options.
+     * Constructs a new CreditCardValidator with the specified {@link CodeValidator}s.
+     * @param creditCardValidators Set of valid code validators
+     */
+    public CreditCardValidator(final CodeValidator[] creditCardValidators) {
+        if (creditCardValidators == null) {
+            throw new IllegalArgumentException("Card validators are missing");
+        }
+        Collections.addAll(cardTypes, creditCardValidators);
+    }
+
+    /**
+     * Constructs a new CreditCardValidator with the specified {@link CodeValidator}s
+     * and {@link CreditCardRange}s.
+     * <p>
+     * This can be used to combine predefined validators such as {@link #MASTERCARD_VALIDATOR}
+     * with additional validators using the simpler {@link CreditCardRange}s.
+     * @param creditCardValidators Set of valid code validators
+     * @param creditCardRanges Set of valid code validators
+     * @since 1.6
+     */
+    public CreditCardValidator(final CodeValidator[] creditCardValidators, final CreditCardRange[] creditCardRanges) {
+        if (creditCardValidators == null) {
+            throw new IllegalArgumentException("Card validators are missing");
+        }
+        if (creditCardRanges == null) {
+            throw new IllegalArgumentException("Card ranges are missing");
+        }
+        Collections.addAll(cardTypes, creditCardValidators);
+        Collections.addAll(cardTypes, createRangeValidator(creditCardRanges, LUHN_VALIDATOR));
+    }
+
+    /**
+     * Constructs a new CreditCardValidator with the specified {@link CreditCardRange}s.
+     * @param creditCardRanges Set of valid code validators
+     * @since 1.6
+     */
+    public CreditCardValidator(final CreditCardRange[] creditCardRanges) {
+        if (creditCardRanges == null) {
+            throw new IllegalArgumentException("Card ranges are missing");
+        }
+        Collections.addAll(cardTypes, createRangeValidator(creditCardRanges, LUHN_VALIDATOR));
+    }
+
+    /**
+     * Constructs a new CreditCardValidator with the specified options.
      * @param options Pass in
      * CreditCardValidator.VISA + CreditCardValidator.AMEX to specify that
      * those are the only valid card types.
      */
-    public CreditCardValidator(long options) {
-        super();
-
+    public CreditCardValidator(final long options) {
         if (isOn(options, VISA)) {
             this.cardTypes.add(VISA_VALIDATOR);
         }
@@ -331,83 +473,16 @@ public class CreditCardValidator implements Serializable {
     }
 
     /**
-     * Create a new CreditCardValidator with the specified {@link CodeValidator}s.
-     * @param creditCardValidators Set of valid code validators
-     */
-    public CreditCardValidator(CodeValidator[] creditCardValidators) {
-        if (creditCardValidators == null) {
-            throw new IllegalArgumentException("Card validators are missing");
-        }
-        Collections.addAll(cardTypes, creditCardValidators);
-    }
-
-    /**
-     * Create a new CreditCardValidator with the specified {@link CreditCardRange}s.
-     * @param creditCardRanges Set of valid code validators
-     * @since 1.6
-     */
-    public CreditCardValidator(CreditCardRange[] creditCardRanges) {
-        if (creditCardRanges == null) {
-            throw new IllegalArgumentException("Card ranges are missing");
-        }
-        Collections.addAll(cardTypes, createRangeValidator(creditCardRanges, LUHN_VALIDATOR));
-    }
-
-    /**
-     * Create a new CreditCardValidator with the specified {@link CodeValidator}s
-     * and {@link CreditCardRange}s.
-     * <p>
-     * This can be used to combine predefined validators such as {@link #MASTERCARD_VALIDATOR}
-     * with additional validators using the simpler {@link CreditCardRange}s.
-     * @param creditCardValidators Set of valid code validators
-     * @param creditCardRanges Set of valid code validators
-     * @since 1.6
-     */
-    public CreditCardValidator(CodeValidator[] creditCardValidators, CreditCardRange[] creditCardRanges) {
-        if (creditCardValidators == null) {
-            throw new IllegalArgumentException("Card validators are missing");
-        }
-        if (creditCardRanges == null) {
-            throw new IllegalArgumentException("Card ranges are missing");
-        }
-        Collections.addAll(cardTypes, creditCardValidators);
-        Collections.addAll(cardTypes, createRangeValidator(creditCardRanges, LUHN_VALIDATOR));
-    }
-
-    /**
-     * Create a new generic CreditCardValidator which validates the syntax and check digit only.
-     * Does not check the Issuer Identification Number (IIN)
+     * Tests whether the given flag is on.  If the flag is not a power of 2
+     * (ie. 3) this tests whether the combination of flags is on.
      *
-     * @param minLen minimum allowed length
-     * @param maxLen maximum allowed length
-     * @return the validator
-     * @since 1.6
-     */
-    public static CreditCardValidator genericCreditCardValidator(int minLen, int maxLen) {
-        return new CreditCardValidator(new CodeValidator[] {new CodeValidator("(\\d+)", minLen, maxLen, LUHN_VALIDATOR)});
-    }
-
-    /**
-     * Create a new generic CreditCardValidator which validates the syntax and check digit only.
-     * Does not check the Issuer Identification Number (IIN)
+     * @param options The options specified.
+     * @param flag Flag value to check.
      *
-     * @param length exact length
-     * @return the validator
-     * @since 1.6
+     * @return whether the specified flag value is on.
      */
-    public static CreditCardValidator genericCreditCardValidator(int length) {
-        return genericCreditCardValidator(length, length);
-    }
-
-    /**
-     * Create a new generic CreditCardValidator which validates the syntax and check digit only.
-     * Does not check the Issuer Identification Number (IIN)
-     *
-     * @return the validator
-     * @since 1.6
-     */
-    public static CreditCardValidator genericCreditCardValidator() {
-        return genericCreditCardValidator(MIN_CC_LENGTH, MAX_CC_LENGTH);
+    private boolean isOn(final long options, final long flag) {
+        return (options & flag) > 0;
     }
 
     /**
@@ -415,11 +490,11 @@ public class CreditCardValidator implements Serializable {
      * @param card The card number to validate.
      * @return Whether the card number is valid.
      */
-    public boolean isValid(String card) {
-        if (card == null || card.length() == 0) {
+    public boolean isValid(final String card) {
+        if (GenericValidator.isBlankOrNull(card)) {
             return false;
         }
-        for (CodeValidator cardType : cardTypes) {
+        for (final CodeValidator cardType : cardTypes) {
             if (cardType.isValid(card)) {
                 return true;
             }
@@ -430,15 +505,15 @@ public class CreditCardValidator implements Serializable {
     /**
      * Checks if the field is a valid credit card number.
      * @param card The card number to validate.
-     * @return The card number if valid or <code>null</code>
+     * @return The card number if valid or {@code null}
      * if invalid.
      */
-    public Object validate(String card) {
-        if (card == null || card.length() == 0) {
+    public Object validate(final String card) {
+        if (GenericValidator.isBlankOrNull(card)) {
             return null;
         }
         Object result = null;
-        for (CodeValidator cardType : cardTypes) {
+        for (final CodeValidator cardType : cardTypes) {
             result = cardType.validate(card);
             if (result != null) {
                 return result;
@@ -448,70 +523,4 @@ public class CreditCardValidator implements Serializable {
 
     }
 
-    // package protected for unit test access
-    static boolean validLength(int valueLength, CreditCardRange range) {
-        if (range.lengths != null) {
-            for(int length : range.lengths) {
-                if (valueLength == length) {
-                    return true;
-                }
-            }
-            return false;
-        }
-        return valueLength >= range.minLen && valueLength <= range.maxLen;
-    }
-
-    // package protected for unit test access
-    static CodeValidator createRangeValidator(final CreditCardRange[] creditCardRanges, final CheckDigit digitCheck ) {
-        return new CodeValidator(
-                // must be numeric (rest of validation is done later)
-                new RegexValidator("(\\d+)") {
-                    private static final long serialVersionUID = 1L;
-                    private CreditCardRange[] ccr = creditCardRanges.clone();
-                    @Override
-                    // must return full string
-                    public String validate(String value) {
-                        if (super.match(value) != null) {
-                            int length = value.length();
-                            for(CreditCardRange range : ccr) {
-                                if (validLength(length, range)) {
-                                    if (range.high == null) { // single prefix only
-                                        if (value.startsWith(range.low)) {
-                                            return value;
-                                        }
-                                    } else if (range.low.compareTo(value) <= 0 // no need to trim value here
-                                                &&
-                                                // here we have to ignore digits beyond the prefix
-                                                range.high.compareTo(value.substring(0, range.high.length())) >= 0) {
-                                               return value;
-                                    }
-                                }
-                            }
-                        }
-                        return null;
-                    }
-                    @Override
-                    public boolean isValid(String value) {
-                        return validate(value) != null;
-                    }
-                    @Override
-                    public String[] match(String value) {
-                        return new String[]{validate(value)};
-                    }
-                }, digitCheck);
-    }
-
-    /**
-     * Tests whether the given flag is on.  If the flag is not a power of 2
-     * (ie. 3) this tests whether the combination of flags is on.
-     *
-     * @param options The options specified.
-     * @param flag Flag value to check.
-     *
-     * @return whether the specified flag value is on.
-     */
-    private boolean isOn(long options, long flag) {
-        return (options & flag) > 0;
-    }
-
 }
