@@ -26,6 +26,8 @@ import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
+import org.apache.commons.validator.GenericValidator;
+
 /**
  * <p><b>URL Validation</b> routines.</p>
  * Behavior of validation is modified by passing in options:
@@ -39,7 +41,7 @@ import java.util.regex.Pattern;
  * </ul>
  *
  * <p>Originally based in on php script by Debbie Dyer, validation.php v1.2b, Date: 03/07/02,
- * http://javascript.internet.com. However, this validation now bears little resemblance
+ * https://javascript.internet.com. However, this validation now bears little resemblance
  * to the php original.</p>
  * <pre>
  *   Example of usage:
@@ -48,22 +50,22 @@ import java.util.regex.Pattern;
  *    String[] schemes = {"http","https"}.
  *    UrlValidator urlValidator = new UrlValidator(schemes);
  *    if (urlValidator.isValid("ftp://foo.bar.com/")) {
- *       System.out.println("url is valid");
+ *       System.out.println("URL is valid");
  *    } else {
- *       System.out.println("url is invalid");
+ *       System.out.println("URL is invalid");
  *    }
  *
- *    prints "url is invalid"
+ *    prints "URL is invalid"
  *   If instead the default constructor is used.
  *
  *    UrlValidator urlValidator = new UrlValidator();
  *    if (urlValidator.isValid("ftp://foo.bar.com/")) {
- *       System.out.println("url is valid");
+ *       System.out.println("URL is valid");
  *    } else {
- *       System.out.println("url is invalid");
+ *       System.out.println("URL is invalid");
  *    }
  *
- *   prints out "url is valid"
+ *   prints out "URL is valid"
  *  </pre>
  *
  * @see
@@ -71,8 +73,7 @@ import java.util.regex.Pattern;
  *  Uniform Resource Identifiers (URI): Generic Syntax
  * </a>
  *
- * @version $Revision$
- * @since Validator 1.4
+ * @since 1.4
  */
 public class UrlValidator implements Serializable {
 
@@ -97,7 +98,7 @@ public class UrlValidator implements Serializable {
     public static final long NO_FRAGMENTS = 1 << 2;
 
     /**
-     * Allow local URLs, such as http://localhost/ or http://machine/ .
+     * Allow local URLs, such as https://localhost/ or https://machine/ .
      * This enables a broad-brush check, for complex local machine name
      *  validation requirements you should create your validator with
      *  a {@link RegexValidator} instead ({@link #UrlValidator(RegexValidator, long)})
@@ -111,7 +112,7 @@ public class UrlValidator implements Serializable {
     private static final Pattern SCHEME_PATTERN = Pattern.compile(SCHEME_REGEX);
 
     // Drop numeric, and  "+-." for now
-    // TODO does not allow for optional userinfo. 
+    // TODO does not allow for optional userinfo.
     // Validation of character set is done by isValidAuthority
     private static final String AUTHORITY_CHARS_REGEX = "\\p{Alnum}\\-\\."; // allows for IPV4 but not IPV6
     // Allow for IPv4 mapped addresses: ::FFF:123.123.123.123
@@ -122,13 +123,15 @@ public class UrlValidator implements Serializable {
     // sub-delims    = "!" / "$" / "&" / "'" / "(" / ")" / "*" / "+" / "," / ";" / "="
     // We assume that password has the same valid chars as user info
     private static final String USERINFO_CHARS_REGEX = "[a-zA-Z0-9%-._~!$&'()*+,;=]";
+
     // since neither ':' nor '@' are allowed chars, we don't need to use non-greedy matching
     private static final String USERINFO_FIELD_REGEX =
             USERINFO_CHARS_REGEX + "+" + // At least one character for the name
             "(?::" + USERINFO_CHARS_REGEX + "*)?@"; // colon and password may be absent
+
     private static final String AUTHORITY_REGEX =
-            "(?:\\[("+IPV6_REGEX+")\\]|(?:(?:"+USERINFO_FIELD_REGEX+")?([" + AUTHORITY_CHARS_REGEX + "]*)))(?::(\\d*))?(.*)?";
-    //             1                          e.g. user:pass@          2                                         3       4
+            "(?:\\[(" + IPV6_REGEX + ")\\]|(?:(?:" + USERINFO_FIELD_REGEX + ")?([" + AUTHORITY_CHARS_REGEX + "]*)))(?::(\\d*))?(.*)?";
+    //             1                                 e.g. user:pass@           2                                       3       4
     private static final Pattern AUTHORITY_PATTERN = Pattern.compile(AUTHORITY_REGEX);
 
     private static final int PARSE_AUTHORITY_IPV6 = 1;
@@ -148,22 +151,6 @@ public class UrlValidator implements Serializable {
     private static final String QUERY_REGEX = "^(\\S*)$";
     private static final Pattern QUERY_PATTERN = Pattern.compile(QUERY_REGEX);
 
-    /**
-     * Holds the set of current validation options.
-     */
-    private final long options;
-
-    /**
-     * The set of schemes that are allowed to be in a URL.
-     */
-    private final Set<String> allowedSchemes; // Must be lower-case
-
-    /**
-     * Regular expressions used to manually validate authorities if IANA
-     * domain name validation isn't desired.
-     */
-    private final RegexValidator authorityValidator;
-
     /**
      * If no schemes are provided, default to this set.
      */
@@ -182,6 +169,35 @@ public class UrlValidator implements Serializable {
         return DEFAULT_URL_VALIDATOR;
     }
 
+    /**
+     * Tests whether the given flag is on.  If the flag is not a power of 2
+     * (e.g. 3) this tests whether the combination of flags is on.
+     *
+     * @param flag Flag value to check.
+     * @param options what to check
+     *
+     * @return whether the specified flag value is on.
+     */
+    private static boolean isOn(final long flag, final long options) {
+        return (options & flag) > 0;
+    }
+
+    /**
+     * Holds the set of current validation options.
+     */
+    private final long options;
+
+    /**
+     * The set of schemes that are allowed to be in a URL.
+     */
+    private final Set<String> allowedSchemes; // Must be lower-case
+
+    /**
+     * Regular expressions used to manually validate authorities if IANA
+     * domain name validation isn't desired.
+     */
+    private final RegexValidator authorityValidator;
+
     private final DomainValidator domainValidator;
 
     /**
@@ -191,39 +207,16 @@ public class UrlValidator implements Serializable {
         this(null);
     }
 
-    /**
-     * Behavior of validation is modified by passing in several strings options:
-     * @param schemes Pass in one or more url schemes to consider valid, passing in
-     *        a null will default to "http,https,ftp" being valid.
-     *        If a non-null schemes is specified then all valid schemes must
-     *        be specified. Setting the ALLOW_ALL_SCHEMES option will
-     *        ignore the contents of schemes.
-     */
-    public UrlValidator(String[] schemes) {
-        this(schemes, 0L);
-    }
-
     /**
      * Initialize a UrlValidator with the given validation options.
      * @param options The options should be set using the public constants declared in
      * this class.  To set multiple options you simply add them together.  For example,
      * ALLOW_2_SLASHES + NO_FRAGMENTS enables both of those options.
      */
-    public UrlValidator(long options) {
+    public UrlValidator(final long options) {
         this(null, null, options);
     }
 
-    /**
-     * Behavior of validation is modified by passing in options:
-     * @param schemes The set of valid schemes. Ignored if the ALLOW_ALL_SCHEMES option is set.
-     * @param options The options should be set using the public constants declared in
-     * this class.  To set multiple options you simply add them together.  For example,
-     * ALLOW_2_SLASHES + NO_FRAGMENTS enables both of those options.
-     */
-    public UrlValidator(String[] schemes, long options) {
-        this(schemes, null, options);
-    }
-
     /**
      * Initialize a UrlValidator with the given validation options.
      * @param authorityValidator Regular expression validator used to validate the authority part
@@ -233,12 +226,35 @@ public class UrlValidator implements Serializable {
      * <p><code>ALLOW_2_SLASHES + NO_FRAGMENTS</code></p>
      * enables both of those options.
      */
-    public UrlValidator(RegexValidator authorityValidator, long options) {
+    public UrlValidator(final RegexValidator authorityValidator, final long options) {
         this(null, authorityValidator, options);
     }
 
     /**
-     * Customizable constructor. Validation behavior is modifed by passing in options.
+     * Behavior of validation is modified by passing in several strings options:
+     * @param schemes Pass in one or more URL schemes to consider valid, passing in
+     *        a null will default to "http,https,ftp" being valid.
+     *        If a non-null schemes is specified then all valid schemes must
+     *        be specified. Setting the ALLOW_ALL_SCHEMES option will
+     *        ignore the contents of schemes.
+     */
+    public UrlValidator(final String[] schemes) {
+        this(schemes, 0L);
+    }
+
+    /**
+     * Behavior of validation is modified by passing in options:
+     * @param schemes The set of valid schemes. Ignored if the ALLOW_ALL_SCHEMES option is set.
+     * @param options The options should be set using the public constants declared in
+     * this class.  To set multiple options you simply add them together.  For example,
+     * ALLOW_2_SLASHES + NO_FRAGMENTS enables both of those options.
+     */
+    public UrlValidator(final String[] schemes, final long options) {
+        this(schemes, null, options);
+    }
+
+    /**
+     * Customizable constructor. Validation behavior is modified by passing in options.
      * @param schemes the set of valid schemes. Ignored if the ALLOW_ALL_SCHEMES option is set.
      * @param authorityValidator Regular expression validator used to validate the authority part
      * @param options Validation options. Set using the public constants of this class.
@@ -246,12 +262,12 @@ public class UrlValidator implements Serializable {
      * <p><code>ALLOW_2_SLASHES + NO_FRAGMENTS</code></p>
      * enables both of those options.
      */
-    public UrlValidator(String[] schemes, RegexValidator authorityValidator, long options) {
+    public UrlValidator(final String[] schemes, final RegexValidator authorityValidator, final long options) {
         this(schemes, authorityValidator, options, DomainValidator.getInstance(isOn(ALLOW_LOCAL_URLS, options)));
     }
 
     /**
-     * Customizable constructor. Validation behavior is modifed by passing in options.
+     * Customizable constructor. Validation behavior is modified by passing in options.
      * @param schemes the set of valid schemes. Ignored if the ALLOW_ALL_SCHEMES option is set.
      * @param authorityValidator Regular expression validator used to validate the authority part
      * @param options Validation options. Set using the public constants of this class.
@@ -261,12 +277,12 @@ public class UrlValidator implements Serializable {
      * @param domainValidator the DomainValidator to use; must agree with ALLOW_LOCAL_URLS setting
      * @since 1.7
      */
-    public UrlValidator(String[] schemes, RegexValidator authorityValidator, long options, DomainValidator domainValidator) {
+    public UrlValidator(String[] schemes, final RegexValidator authorityValidator, final long options, final DomainValidator domainValidator) {
         this.options = options;
         if (domainValidator == null) {
             throw new IllegalArgumentException("DomainValidator must not be null");
         }
-        if (domainValidator.isAllowLocal() != ((options & ALLOW_LOCAL_URLS) > 0)){
+        if (domainValidator.isAllowLocal() != (options & ALLOW_LOCAL_URLS) > 0) {
             throw new IllegalArgumentException("DomainValidator disagrees with ALLOW_LOCAL_URLS setting");
         }
         this.domainValidator = domainValidator;
@@ -278,8 +294,8 @@ public class UrlValidator implements Serializable {
                 schemes = DEFAULT_SCHEMES;
             }
             allowedSchemes = new HashSet<>(schemes.length);
-            for(int i=0; i < schemes.length; i++) {
-                allowedSchemes.add(schemes[i].toLowerCase(Locale.ENGLISH));
+            for (final String scheme : schemes) {
+                allowedSchemes.add(scheme.toLowerCase(Locale.ENGLISH));
             }
         }
 
@@ -287,16 +303,59 @@ public class UrlValidator implements Serializable {
     }
 
     /**
-     * <p>Checks if a field has a valid url address.</p>
+     * Returns the number of times the token appears in the target.
+     * @param token Token value to be counted.
+     * @param target Target value to count tokens in.
+     * @return the number of tokens.
+     */
+    protected int countToken(final String token, final String target) {
+        int tokenIndex = 0;
+        int count = 0;
+        while (tokenIndex != -1) {
+            tokenIndex = target.indexOf(token, tokenIndex);
+            if (tokenIndex > -1) {
+                tokenIndex++;
+                count++;
+            }
+        }
+        return count;
+    }
+
+    /**
+     * Tests whether the given flag is off.  If the flag is not a power of 2
+     * (ie. 3) this tests whether the combination of flags is off.
+     *
+     * @param flag Flag value to check.
+     *
+     * @return whether the specified flag value is off.
+     */
+    private boolean isOff(final long flag) {
+        return (options & flag) == 0;
+    }
+
+    /**
+     * Tests whether the given flag is on.  If the flag is not a power of 2
+     * (ie. 3) this tests whether the combination of flags is on.
+     *
+     * @param flag Flag value to check.
+     *
+     * @return whether the specified flag value is on.
+     */
+    private boolean isOn(final long flag) {
+        return (options & flag) > 0;
+    }
+
+    /**
+     * <p>Checks if a field has a valid URL address.</p>
      *
      * Note that the method calls #isValidAuthority()
      * which checks that the domain is valid.
      *
-     * @param value The value validation is being performed on.  A <code>null</code>
+     * @param value The value validation is being performed on.  A {@code null}
      * value is considered invalid.
-     * @return true if the url is valid.
+     * @return true if the URL is valid.
      */
-    public boolean isValid(String value) {
+    public boolean isValid(final String value) {
         if (value == null) {
             return false;
         }
@@ -304,26 +363,26 @@ public class UrlValidator implements Serializable {
         URI uri; // ensure value is a valid URI
         try {
             uri = new URI(value);
-        } catch (URISyntaxException e) {
+        } catch (final URISyntaxException e) {
             return false;
         }
-        // OK, perfom additional validation
+        // OK, perform additional validation
 
-        String scheme = uri.getScheme();
+        final String scheme = uri.getScheme();
         if (!isValidScheme(scheme)) {
             return false;
         }
 
-        String authority = uri.getRawAuthority();
-        if ("file".equals(scheme) && (authority == null || "".equals(authority))) {// Special case - file: allows an empty authority
+        final String authority = uri.getRawAuthority();
+        if ("file".equals(scheme) && GenericValidator.isBlankOrNull(authority)) { // Special case - file: allows an empty authority
             return true; // this is a local file - nothing more to do here
-        } else if ("file".equals(scheme) && authority != null && authority.contains(":")) {
+        }
+        if ("file".equals(scheme) && authority != null && authority.contains(":")) {
+            return false;
+        }
+        // Validate the authority
+        if (!isValidAuthority(authority)) {
             return false;
-        } else {
-            // Validate the authority
-            if (!isValidAuthority(authority)) {
-                return false;
-            }
         }
 
         if (!isValidPath(uri.getRawPath())) {
@@ -341,16 +400,142 @@ public class UrlValidator implements Serializable {
         return true;
     }
 
+    /**
+     * Returns true if the authority is properly formatted.  An authority is the combination
+     * of hostname and port.  A {@code null} authority value is considered invalid.
+     * Note: this implementation validates the domain unless a RegexValidator was provided.
+     * If a RegexValidator was supplied and it matches, then the authority is regarded
+     * as valid with no further checks, otherwise the method checks against the
+     * AUTHORITY_PATTERN and the DomainValidator (ALLOW_LOCAL_URLS)
+     * @param authority Authority value to validate, alllows IDN
+     * @return true if authority (hostname and port) is valid.
+     */
+    protected boolean isValidAuthority(final String authority) {
+        if (authority == null) {
+            return false;
+        }
+
+        // check manual authority validation if specified
+        if (authorityValidator != null && authorityValidator.isValid(authority)) {
+            return true;
+        }
+        // convert to ASCII if possible
+        final String authorityASCII = DomainValidator.unicodeToASCII(authority);
+
+        final Matcher authorityMatcher = AUTHORITY_PATTERN.matcher(authorityASCII);
+        if (!authorityMatcher.matches()) {
+            return false;
+        }
+
+        // We have to process IPV6 separately because that is parsed in a different group
+        final String ipv6 = authorityMatcher.group(PARSE_AUTHORITY_IPV6);
+        if (ipv6 != null) {
+            final InetAddressValidator inetAddressValidator = InetAddressValidator.getInstance();
+            if (!inetAddressValidator.isValidInet6Address(ipv6)) {
+                return false;
+            }
+        } else {
+            final String hostLocation = authorityMatcher.group(PARSE_AUTHORITY_HOST_IP);
+            // check if authority is hostname or IP address:
+            // try a hostname first since that's much more likely
+            if (!this.domainValidator.isValid(hostLocation)) {
+                // try an IPv4 address
+                final InetAddressValidator inetAddressValidator = InetAddressValidator.getInstance();
+                if (!inetAddressValidator.isValidInet4Address(hostLocation)) {
+                    // isn't IPv4, so the URL is invalid
+                    return false;
+                }
+            }
+            final String port = authorityMatcher.group(PARSE_AUTHORITY_PORT);
+            if (!GenericValidator.isBlankOrNull(port)) {
+                try {
+                    final int iPort = Integer.parseInt(port);
+                    if (iPort < 0 || iPort > MAX_UNSIGNED_16_BIT_INT) {
+                        return false;
+                    }
+                } catch (final NumberFormatException nfe) {
+                    return false; // this can happen for big numbers
+                }
+            }
+        }
+
+        final String extra = authorityMatcher.group(PARSE_AUTHORITY_EXTRA);
+        if (extra != null && !extra.trim().isEmpty()) {
+            return false;
+        }
+
+        return true;
+    }
+
+    /**
+     * Returns true if the given fragment is null or fragments are allowed.
+     * @param fragment Fragment value to validate.
+     * @return true if fragment is valid.
+     */
+    protected boolean isValidFragment(final String fragment) {
+        if (fragment == null) {
+            return true;
+        }
+
+        return isOff(NO_FRAGMENTS);
+    }
+
+    /**
+     * Returns true if the path is valid.  A {@code null} value is considered invalid.
+     * @param path Path value to validate.
+     * @return true if path is valid.
+     */
+    protected boolean isValidPath(final String path) {
+        if (path == null) {
+            return false;
+        }
+
+        if (!PATH_PATTERN.matcher(path).matches()) {
+            return false;
+        }
+
+        try {
+            // Don't omit host otherwise leading path may be taken as host if it starts with //
+            final URI uri = new URI(null, "localhost", path, null);
+            final String norm = uri.normalize().getPath();
+            if (norm.startsWith("/../") // Trying to go via the parent dir
+                    || norm.equals("/..")) { // Trying to go to the parent dir
+                return false;
+            }
+        } catch (final URISyntaxException e) {
+            return false;
+        }
+
+        final int slash2Count = countToken("//", path);
+        if (isOff(ALLOW_2_SLASHES) && slash2Count > 0) {
+            return false;
+        }
+
+        return true;
+    }
+
+    /**
+     * Returns true if the query is null or it's a properly formatted query string.
+     * @param query Query value to validate.
+     * @return true if query is valid.
+     */
+    protected boolean isValidQuery(final String query) {
+        if (query == null) {
+            return true;
+        }
+        return QUERY_PATTERN.matcher(query).matches();
+    }
+
     /**
      * Validate scheme. If schemes[] was initialized to a non null,
      * then only those schemes are allowed.
      * Otherwise the default schemes are "http", "https", "ftp".
      * Matching is case-blind.
-     * @param scheme The scheme to validate.  A <code>null</code> value is considered
+     * @param scheme The scheme to validate.  A {@code null} value is considered
      * invalid.
      * @return true if valid.
      */
-    protected boolean isValidScheme(String scheme) {
+    protected boolean isValidScheme(final String scheme) {
         if (scheme == null) {
             return false;
         }
@@ -366,187 +551,4 @@ public class UrlValidator implements Serializable {
         return true;
     }
 
-    /**
-     * Returns true if the authority is properly formatted.  An authority is the combination
-     * of hostname and port.  A <code>null</code> authority value is considered invalid.
-     * Note: this implementation validates the domain unless a RegexValidator was provided.
-     * If a RegexValidator was supplied and it matches, then the authority is regarded
-     * as valid with no further checks, otherwise the method checks against the
-     * AUTHORITY_PATTERN and the DomainValidator (ALLOW_LOCAL_URLS)
-     * @param authority Authority value to validate, alllows IDN
-     * @return true if authority (hostname and port) is valid.
-     */
-    protected boolean isValidAuthority(String authority) {
-        if (authority == null) {
-            return false;
-        }
-
-        // check manual authority validation if specified
-        if (authorityValidator != null && authorityValidator.isValid(authority)) {
-            return true;
-        }
-        // convert to ASCII if possible
-        final String authorityASCII = DomainValidator.unicodeToASCII(authority);
-
-        Matcher authorityMatcher = AUTHORITY_PATTERN.matcher(authorityASCII);
-        if (!authorityMatcher.matches()) {
-            return false;
-        }
-
-        // We have to process IPV6 separately because that is parsed in a different group
-        String ipv6 = authorityMatcher.group(PARSE_AUTHORITY_IPV6);
-        if (ipv6 != null) {
-            InetAddressValidator inetAddressValidator = InetAddressValidator.getInstance();
-                if (!inetAddressValidator.isValidInet6Address(ipv6)) {
-                    return false;
-                }
-        } else {
-            String hostLocation = authorityMatcher.group(PARSE_AUTHORITY_HOST_IP);
-            // check if authority is hostname or IP address:
-            // try a hostname first since that's much more likely
-            if (!this.domainValidator.isValid(hostLocation)) {
-                // try an IPv4 address
-                InetAddressValidator inetAddressValidator = InetAddressValidator.getInstance();
-                if (!inetAddressValidator.isValidInet4Address(hostLocation)) {
-                    // isn't IPv4, so the URL is invalid
-                    return false;
-                }
-            }
-            String port = authorityMatcher.group(PARSE_AUTHORITY_PORT);
-            if (port != null && port.length() > 0) {
-                try {
-                    int iPort = Integer.parseInt(port);
-                    if (iPort < 0 || iPort > MAX_UNSIGNED_16_BIT_INT) {
-                        return false;
-                    }
-                } catch (NumberFormatException nfe) {
-                    return false; // this can happen for big numbers
-                }
-            }
-        }
-
-        String extra = authorityMatcher.group(PARSE_AUTHORITY_EXTRA);
-        if (extra != null && extra.trim().length() > 0){
-            return false;
-        }
-
-        return true;
-    }
-
-    /**
-     * Returns true if the path is valid.  A <code>null</code> value is considered invalid.
-     * @param path Path value to validate.
-     * @return true if path is valid.
-     */
-    protected boolean isValidPath(String path) {
-        if (path == null) {
-            return false;
-        }
-
-        if (!PATH_PATTERN.matcher(path).matches()) {
-            return false;
-        }
-
-        try {
-            // Don't omit host otherwise leading path may be taken as host if it starts with //
-            URI uri = new URI(null,"localhost",path,null);
-            String norm = uri.normalize().getPath();
-            if (norm.startsWith("/../") // Trying to go via the parent dir 
-             || norm.equals("/..")) {   // Trying to go to the parent dir
-                return false;
-            }
-        } catch (URISyntaxException e) {
-            return false;
-        }
-        
-        int slash2Count = countToken("//", path);
-        if (isOff(ALLOW_2_SLASHES) && (slash2Count > 0)) {
-            return false;
-        }
-
-        return true;
-    }
-
-    /**
-     * Returns true if the query is null or it's a properly formatted query string.
-     * @param query Query value to validate.
-     * @return true if query is valid.
-     */
-    protected boolean isValidQuery(String query) {
-        if (query == null) {
-            return true;
-        }
-
-        return QUERY_PATTERN.matcher(query).matches();
-    }
-
-    /**
-     * Returns true if the given fragment is null or fragments are allowed.
-     * @param fragment Fragment value to validate.
-     * @return true if fragment is valid.
-     */
-    protected boolean isValidFragment(String fragment) {
-        if (fragment == null) {
-            return true;
-        }
-
-        return isOff(NO_FRAGMENTS);
-    }
-
-    /**
-     * Returns the number of times the token appears in the target.
-     * @param token Token value to be counted.
-     * @param target Target value to count tokens in.
-     * @return the number of tokens.
-     */
-    protected int countToken(String token, String target) {
-        int tokenIndex = 0;
-        int count = 0;
-        while (tokenIndex != -1) {
-            tokenIndex = target.indexOf(token, tokenIndex);
-            if (tokenIndex > -1) {
-                tokenIndex++;
-                count++;
-            }
-        }
-        return count;
-    }
-
-    /**
-     * Tests whether the given flag is on.  If the flag is not a power of 2
-     * (ie. 3) this tests whether the combination of flags is on.
-     *
-     * @param flag Flag value to check.
-     *
-     * @return whether the specified flag value is on.
-     */
-    private boolean isOn(long flag) {
-        return (options & flag) > 0;
-    }
-
-    /**
-     * Tests whether the given flag is on.  If the flag is not a power of 2
-     * (e.g. 3) this tests whether the combination of flags is on.
-     *
-     * @param flag Flag value to check.
-     * @param options what to check
-     *
-     * @return whether the specified flag value is on.
-     */
-    private static boolean isOn(long flag, long options) {
-        return (options & flag) > 0;
-    }
-
-    /**
-     * Tests whether the given flag is off.  If the flag is not a power of 2
-     * (ie. 3) this tests whether the combination of flags is off.
-     *
-     * @param flag Flag value to check.
-     *
-     * @return whether the specified flag value is off.
-     */
-    private boolean isOff(long flag) {
-        return (options & flag) == 0;
-    }
-
 }
