@@ -16,33 +16,27 @@
  */
 package org.apache.commons.validator;
 
+import static org.junit.jupiter.api.Assertions.fail;
+
 import java.io.InputStream;
 
-import junit.framework.TestCase;
+import org.junit.jupiter.api.Test;
 
 /**
  * Test ValidatorResources.
- *
- * @version $Revision$
  */
-public class ValidatorResourcesTest extends TestCase {
-
-    /**
-     * Constructor.
-     */
-    public ValidatorResourcesTest(String name) {
-        super(name);
-    }
+public class ValidatorResourcesTest {
 
     /**
      * Test null Input Stream for Validator Resources.
      */
+    @Test
     public void testNullInputStream() throws Exception {
 
         try {
-            new ValidatorResources((InputStream)null);
+            new ValidatorResources((InputStream) null);
             fail("Expected IllegalArgumentException");
-        } catch(IllegalArgumentException e) {
+        } catch (final IllegalArgumentException e) {
             // expected result
             // System.out.println("Exception: " + e);
         }
